TrustedCheckpoint

Trait TrustedCheckpoint 

pub trait TrustedCheckpoint {
    // Required method
    fn is_current_checkpoint(&self, exact_pca_bytes: &[u8]) -> bool;
}
The settlement authority’s knowledge of currently trusted checkpoints.

root.pca of a candidate must be the exact signed bytes of a currently trusted PIC PCA COSE checkpoint; the store answers that question. Terminating a checkpoint here is how revocation of a lineage branch is realized operationally.

Required Methods

fn is_current_checkpoint(&self, exact_pca_bytes: &[u8]) -> bool

true when exact_pca_bytes are byte-for-byte a currently trusted checkpoint.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors